@@ -1,6 +1,6 @@
 package PAUSE::Users::User;
 {
-  $PAUSE::Users::User::VERSION = '0.01';
+  $PAUSE::Users::User::VERSION = '0.02';
 }
 
 use 5.10.0;
@@ -9,11 +9,9 @@ use Moo;
 has 'asciiname'     => (is => 'ro');
 has 'email'         => (is => 'ro');
 has 'fullname'      => (is => 'ro');
-has 'has_cpandir'   => (is => 'ro');
+has 'has_cpandir'   => (is => 'ro', default => sub { 0 } );
 has 'homepage'      => (is => 'ro');
 has 'id'            => (is => 'ro');
-has 'info'          => (is => 'ro');
 has 'introduced'    => (is => 'ro');
-has 'type'          => (is => 'ro');
 
 1;
